@@ -5,18 +5,22 @@ use strict;
 
 =head1 NAME
 
-App::Ack - A container for functions for the ack program
+App::Ack
+
+=head1 DESCRIPTION
+
+A container for functions for the ack program.
 
 =head1 VERSION
 
-Version 2.17_02
+Version 2.19_01
 
 =cut
 
 our $VERSION;
 our $COPYRIGHT;
 BEGIN {
-    $VERSION = '2.17_02';
+    $VERSION = '2.19_01';
     $COPYRIGHT = 'Copyright 2005-2017 Andy Lester.';
 }
 
@@ -111,19 +115,15 @@ sub filetypes_supported {
     return keys %mappings;
 }
 
-sub _get_thpppt {
+sub thpppt {
     my $y = q{_   /|,\\'!.x',=(www)=,   U   };
     $y =~ tr/,x!w/\nOo_/;
-    return $y;
-}
 
-sub _thpppt {
-    my $y = _get_thpppt();
     App::Ack::print( "$y ack $_[0]!\n" );
     exit 0;
 }
 
-sub _bar {
+sub ackbar {
     my $x;
     $x = <<'_BAR';
  6?!I'7!I"?%+!
@@ -166,10 +166,10 @@ sub _bar {
 77I!+!7!?!7!I"71+!7,
 _BAR
 
-    return App::Ack::__pic($x);
+    return _pic_decode($x);
 }
 
-sub _cathy {
+sub cathy {
     my $x = <<'CATHY';
  0+!--+!
  0|! "C!H!O!C!O!L!A!T!E!!! !|!
@@ -222,10 +222,10 @@ sub _cathy {
  0?!$! &N! )." .,! %."M! ":!M!.! 0
  0N!:! %?!O! #.! ..! &,! &.!D!,! "N!I! 0
 CATHY
-    return App::Ack::__pic($x);
+    return _pic_decode($x);
 }
 
-sub __pic {
+sub _pic_decode {
     my($compressed) = @_;
     $compressed =~ s/(.)(.)/$1x(ord($2)-32)/eg;
     App::Ack::print( $compressed );
@@ -491,49 +491,9 @@ sub get_copyright {
 }
 
 
-# print*() subs added in order to make it easy for a third party
-# module (such as App::Wack) to redefine the display methods
-# and show the results in a different way.
 sub print                   { print {$fh} @_; return; }
-sub print_first_filename    { App::Ack::print( $_[0], "\n" ); return; }
 sub print_blank_line        { App::Ack::print( "\n" ); return; }
-sub print_separator         { App::Ack::print( "--\n" ); return; }
 sub print_filename          { App::Ack::print( $_[0], $_[1] ); return; }
-sub print_line_no           { App::Ack::print( $_[0], $_[1] ); return; }
-sub print_column_no         { App::Ack::print( $_[0], $_[1] ); return; }
-sub print_count {
-    my $filename = shift;
-    my $nmatches = shift;
-    my $ors = shift;
-    my $count = shift;
-    my $show_filename = shift;
-
-    if ($show_filename) {
-        App::Ack::print( $filename );
-        App::Ack::print( ':', $nmatches ) if $count;
-    }
-    else {
-        App::Ack::print( $nmatches ) if $count;
-    }
-    App::Ack::print( $ors );
-
-    return;
-}
-
-sub print_count0 {
-    my $filename = shift;
-    my $ors = shift;
-    my $show_filename = shift;
-
-    if ($show_filename) {
-        App::Ack::print( $filename, ':0', $ors );
-    }
-    else {
-        App::Ack::print( '0', $ors );
-    }
-
-    return;
-}
 
 sub set_up_pager {
     my $command = shift;
